# Blackchirp Python Package

Blackchirp is an open-source data acquisition program for chirped-pulse Fourier transform microwave spectroscopy. This package contains classes for reading Blackchirp data from disk and performing common processing tasks (Fourier transforms, etc). For more information, see the [Blackchirp GitHub repository](https://github.com/kncrabtree/blackchirp) and the [documentation](https://blackchirp.readthedocs.io/en/latest/).
